@@ -1,29 +1,31 @@
 #include "crashmail.h"
 
+static size_t ptrsize = sizeof(void *);
+
 void SendRemoteAreafix(void);
-struct Arealist *FindForward(uchar *tagname,uchar *flags);
-void RemoteAreafixAdd(uchar *area,struct ConfigNode *node);
-void RemoteAreafixRemove(uchar *area,struct ConfigNode *node);
-bool CheckFlags(uchar group,uchar *node);
+struct Arealist *FindForward(char *tagname,char *flags);
+void RemoteAreafixAdd(char *area,struct ConfigNode *node);
+void RemoteAreafixRemove(char *area,struct ConfigNode *node);
+bool CheckFlags(char group,char *node);
 
 struct afReply
 {
    struct MemMessage *mm;
-	uchar subject[72];
-	ulong lines;
-	ulong part;
+	char subject[72];
+	uint32_t lines;
+	uint32_t part;
 };
 
-struct afReply *afInitReply(uchar *fromname,struct Node4D *from4d,uchar *toname,struct Node4D *to4d,uchar *subject);
+struct afReply *afInitReply(char *fromname,struct Node4D *from4d,char *toname,struct Node4D *to4d,char *subject);
 void afFreeReply(struct afReply *af);
-void afAddLine(struct afReply *af,uchar *fmt,...);
+void afAddLine(struct afReply *af,char *fmt,...);
 void afSendMessage(struct afReply *af);
 
-void AddCommandReply(struct afReply *af,uchar *cmd,uchar *reply);
+void AddCommandReply(struct afReply *af,char *cmd,char *reply);
 
-void rawSendList(short type,struct Node4D *from4d,uchar *toname,struct ConfigNode *cnode);
-void rawSendHelp(struct Node4D *from4d,uchar *toname,struct ConfigNode *cnode);
-void rawSendInfo(struct Node4D *from4d,uchar *toname,struct ConfigNode *cnode);
+void rawSendList(short type,struct Node4D *from4d,char *toname,struct ConfigNode *cnode);
+void rawSendHelp(struct Node4D *from4d,char *toname,struct ConfigNode *cnode);
+void rawSendInfo(struct Node4D *from4d,char *toname,struct ConfigNode *cnode);
 
 void SendRemoveMessages(struct Area *area);
 void RemoveDeletedAreas(void);
@@ -40,11 +42,11 @@ bool AreaFix(struct MemMessage *mm)
    struct TossNode   *temptnode;
    struct BannedNode *bannednode;
    struct TextChunk *chunk;
-   ulong c,d,q,jbcpos;
-   uchar password[100],buf[100],buf2[100];
+   uint32_t c,d,q,jbcpos;
+   char password[100],buf[100],buf2[100];
    bool stop,sendareaquery,sendarealist,sendareaunlinked,sendhelp,sendinfo,done,iswild;
    bool globalrescan,wasfeed;
-   uchar *opt,areaname[100],command;
+   char *opt,areaname[100],command;
    struct Route *tmproute;
    struct afReply *afr;
 		
@@ -291,7 +293,7 @@ bool AreaFix(struct MemMessage *mm)
          }
          else if(buf[0]!=1 && buf[0]!=0)
          {
-            ulong rescannum;
+            uint32_t rescannum;
             bool patterndone,dorescan,areaexists,success;
             struct Area *rescanarea;
 
@@ -586,8 +588,8 @@ bool AreaFix(struct MemMessage *mm)
 	                              return(FALSE);
 										}
 
-                              LogWrite(4,AREAFIX,"AreaFix: Rescanned %lu messages",rescan_total);
-                              afAddLine(afr,"%-30.30s Rescanned %lu messages","",rescan_total);
+                              LogWrite(4,AREAFIX,"AreaFix: Rescanned %u messages",rescan_total);
+                              afAddLine(afr,"%-30.30s Rescanned %u messages","",rescan_total);
                            }
                         }
                         else
@@ -617,9 +619,9 @@ bool AreaFix(struct MemMessage *mm)
 
                                  if(arealist)
                                  {
-												uchar buf2[100];
+												char buf2[100];
 
-                                    LogWrite(3,AREAFIX,"AreaFix: %s requested from %lu:%lu/%lu.%lu",areaname,arealist->Node->Node.Zone,arealist->Node->Node.Net,arealist->Node->Node.Node,arealist->Node->Node.Point);
+                                    LogWrite(3,AREAFIX,"AreaFix: %s requested from %u:%u/%u.%u",areaname,arealist->Node->Node.Zone,arealist->Node->Node.Net,arealist->Node->Node.Node,arealist->Node->Node.Point);
 
                                     sprintf(buf2,"Request sent to %u:%u/%u.%u",arealist->Node->Node.Zone,arealist->Node->Node.Net,arealist->Node->Node.Node,arealist->Node->Node.Point);
 												AddCommandReply(afr,buf,buf2);
@@ -630,7 +632,7 @@ bool AreaFix(struct MemMessage *mm)
 
                                     if(area)
                                     {
-                                       ushort flags;
+                                       uint16_t flags;
 
                                        flags=0;
 
@@ -730,14 +732,14 @@ bool AreaFix(struct MemMessage *mm)
 void SendRemoveMessages(struct Area *area)
 {
    struct TossNode *tn;
-   uchar buf[100];
+   char buf[100];
    struct MemMessage *mm;
 	
    for(tn=(struct TossNode *)area->TossNodes.First;tn;tn=tn->Next)
    {
       if(tn->ConfigNode->Flags & NODE_SENDAREAFIX)
       {
-         LogWrite(5,AREAFIX,"AreaFix: Sending message to AreaFix at %ld:%ld/%ld.%ld",
+         LogWrite(5,AREAFIX,"AreaFix: Sending message to AreaFix at %d:%d/%d.%d",
             tn->ConfigNode->Node.Zone,
             tn->ConfigNode->Node.Net,
             tn->ConfigNode->Node.Node,
@@ -780,7 +782,7 @@ void SendRemoveMessages(struct Area *area)
 
       if((tn->ConfigNode->Flags & NODE_SENDTEXT) && !(tn->Flags & TOSSNODE_FEED))
       {
-         LogWrite(5,AREAFIX,"AreaFix: Notifying sysop at %ld:%ld/%ld.%ld",
+         LogWrite(5,AREAFIX,"AreaFix: Notifying sysop at %d:%d/%d.%d",
             tn->ConfigNode->Node.Zone,
             tn->ConfigNode->Node.Net,
             tn->ConfigNode->Node.Node,
@@ -847,23 +849,23 @@ void RemoveDeletedAreas(void)
 struct StatsNode
 {
    struct StatsNode *Next;
-   uchar *Tagname;
-   uchar *Desc;
-   uchar Group;
+   char *Tagname;
+   char *Desc;
+   char Group;
    bool Attached;
    bool Feed;
-   ulong WeekKB; /* -1 means unknown */
+   uint32_t WeekKB; /* -1 means unknown */
 };
 
 struct jbList SortList;
 
-bool AddSortList(uchar *tagname,uchar *desc,uchar group,bool attached,bool feed,long weekkb)
+bool AddSortList(char *tagname,char *desc,char group,bool attached,bool feed,long weekkb)
 {
-   uchar *mtagname,*mdesc;
+   char *mtagname,*mdesc;
    struct StatsNode *ss;
 
-   mtagname=(uchar *)osAlloc(strlen(tagname)+1);
-   mdesc=(uchar *)osAlloc(strlen(desc)+1);
+   mtagname=(char *)osAlloc(strlen(tagname)+1);
+   mdesc=(char *)osAlloc(strlen(desc)+1);
    ss=(struct StatsNode *)osAlloc(sizeof(struct StatsNode));
 
    if(!mtagname || !mdesc || !ss)
@@ -918,7 +920,7 @@ int CompareAreas(const void *a1,const void *a2)
 
 void SortSortList(void)
 {
-   ulong nc;
+   uint32_t nc;
    struct StatsNode *ss,**buf,**work;
 
    nc=0;
@@ -940,7 +942,7 @@ void SortSortList(void)
    for(ss=(struct StatsNode *)SortList.First;ss;ss=ss->Next)
       *work++=ss;
 
-   qsort(buf,nc,4,CompareAreas);
+   qsort(buf,nc,ptrsize,CompareAreas);
 
    jbNewList(&SortList);
 
@@ -987,15 +989,15 @@ bool AddForwardList(struct Arealist *arealist)
 {
    bool res;
    osFile fh;
-   uchar buf[200];
-   uchar desc[100];
-   ulong c,d;
+   char buf[200];
+   char desc[100];
+   uint32_t c,d;
    struct Area *area;
    struct StatsNode *ss;
    
    if(!(fh=osOpen(arealist->AreaFile,MODE_OLDFILE)))
    {
-		ulong err=osError();
+		uint32_t err=osError();
       LogWrite(1,SYSTEMERR,"AreaFix: File %s not found",arealist->AreaFile);
 		LogWrite(1,SYSTEMERR,"AreaFix: Error: %s",osErrorMsg(err));
       return(TRUE);
@@ -1053,7 +1055,7 @@ bool AddForwardList(struct Arealist *arealist)
    return(TRUE);
 }
 
-void AddCommandReply(struct afReply *afr,uchar *cmd,uchar *reply)
+void AddCommandReply(struct afReply *afr,char *cmd,char *reply)
 {
 	if(strlen(cmd) <= 30)
 	{
@@ -1066,22 +1068,22 @@ void AddCommandReply(struct afReply *afr,uchar *cmd,uchar *reply)
 	}	
 }
 
-void rawSendList(short type,struct Node4D *from4d,uchar *toname,struct ConfigNode *cnode)
+void rawSendList(short type,struct Node4D *from4d,char *toname,struct ConfigNode *cnode)
 {
-   uchar buf[50];
+   char buf[50];
    struct TossNode *tn;
    struct Area *area;
    struct StatsNode *ss,*lastss;
    struct Arealist *arealist;
    short sendlisttotal,sendlistlinked;
-   uchar ast;
+   char ast;
    struct afReply *afr;
    /* Log action */
 
    switch(type)
    {
       case SENDLIST_QUERY:
-         LogWrite(4,AREAFIX,"AreaFix: Sending query to %lu:%lu/%lu.%lu",
+         LogWrite(4,AREAFIX,"AreaFix: Sending query to %u:%u/%u.%u",
             cnode->Node.Zone,
             cnode->Node.Net,
             cnode->Node.Node,
@@ -1090,7 +1092,7 @@ void rawSendList(short type,struct Node4D *from4d,uchar *toname,struct ConfigNod
          break;
 
       case SENDLIST_UNLINKED:
-         LogWrite(4,AREAFIX,"AreaFix: Sending list of unlinked areas to %lu:%lu/%lu.%lu",
+         LogWrite(4,AREAFIX,"AreaFix: Sending list of unlinked areas to %u:%u/%u.%u",
             cnode->Node.Zone,
             cnode->Node.Net,
             cnode->Node.Node,
@@ -1099,7 +1101,7 @@ void rawSendList(short type,struct Node4D *from4d,uchar *toname,struct ConfigNod
          break;
 
       case SENDLIST_FULL:
-         LogWrite(4,AREAFIX,"AreaFix: Sending list of areas to %lu:%lu/%lu.%lu",
+         LogWrite(4,AREAFIX,"AreaFix: Sending list of areas to %u:%u/%u.%u",
             cnode->Node.Zone,
             cnode->Node.Net,
             cnode->Node.Node,
@@ -1116,7 +1118,7 @@ void rawSendList(short type,struct Node4D *from4d,uchar *toname,struct ConfigNod
    switch(type)
    {
       case SENDLIST_QUERY:
-         afAddLine(afr,"This is a list of all connected areas at %lu:%lu/%lu.%lu:",
+         afAddLine(afr,"This is a list of all connected areas at %u:%u/%u.%u:",
             from4d->Zone,
             from4d->Net,
             from4d->Node,
@@ -1124,7 +1126,7 @@ void rawSendList(short type,struct Node4D *from4d,uchar *toname,struct ConfigNod
          break;
 
       case SENDLIST_FULL:
-         afAddLine(afr,"This is a list of all available areas at %lu:%lu/%lu.%lu:",
+         afAddLine(afr,"This is a list of all available areas at %u:%u/%u.%u:",
             from4d->Zone,
             from4d->Net,
             from4d->Node,
@@ -1132,7 +1134,7 @@ void rawSendList(short type,struct Node4D *from4d,uchar *toname,struct ConfigNod
          break;
 
       case SENDLIST_UNLINKED:
-         afAddLine(afr,"This is a list of all unlinked areas at %lu:%lu/%lu.%lu:",
+         afAddLine(afr,"This is a list of all unlinked areas at %u:%u/%u.%u:",
             from4d->Zone,
             from4d->Net,
             from4d->Node,
@@ -1255,7 +1257,7 @@ void rawSendList(short type,struct Node4D *from4d,uchar *toname,struct ConfigNod
          strcpy(buf,"?");
 
       else
-         sprintf(buf,"%ld",ss->WeekKB);
+         sprintf(buf,"%d",ss->WeekKB);
 
       if(strlen(ss->Tagname)<=28)
       {
@@ -1272,16 +1274,16 @@ void rawSendList(short type,struct Node4D *from4d,uchar *toname,struct ConfigNod
    switch(type)
    {
       case SENDLIST_QUERY:
-         afAddLine(afr,"\x0d%lu linked areas.",sendlisttotal);
+         afAddLine(afr,"\x0d%u linked areas.",sendlisttotal);
          afAddLine(afr,"A '%%' means that you are the feed for the area.");
          break;
 
       case SENDLIST_UNLINKED:
-         afAddLine(afr,"\x0d%lu unlinked areas.",sendlisttotal);
+         afAddLine(afr,"\x0d%u unlinked areas.",sendlisttotal);
          break;
 
       case SENDLIST_FULL:
-         afAddLine(afr,"\x0dTotally %lu areas, you are connected to %lu of them.",sendlisttotal,sendlistlinked);
+         afAddLine(afr,"\x0dTotally %u areas, you are connected to %u of them.",sendlisttotal,sendlistlinked);
          afAddLine(afr,"A '*' means that you are connected to the area.");
          afAddLine(afr,"A '%%' means that you are the feed for the area.");
          break;
@@ -1292,13 +1294,13 @@ void rawSendList(short type,struct Node4D *from4d,uchar *toname,struct ConfigNod
    FreeSortList();
 }
 
-void rawSendHelp(struct Node4D *from4d,uchar *toname,struct ConfigNode *cnode)
+void rawSendHelp(struct Node4D *from4d,char *toname,struct ConfigNode *cnode)
 {
-   uchar helpbuf[100];
+   char helpbuf[100];
    osFile fh;
 	struct afReply *afr;
 	
-   LogWrite(4,AREAFIX,"AreaFix: Sending help file to %lu:%lu/%lu.%lu",
+   LogWrite(4,AREAFIX,"AreaFix: Sending help file to %u:%u/%u.%u",
       cnode->Node.Zone,
       cnode->Node.Net,
       cnode->Node.Node,
@@ -1309,7 +1311,7 @@ void rawSendHelp(struct Node4D *from4d,uchar *toname,struct ConfigNode *cnode)
 
    if(!(fh=osOpen(config.cfg_AreaFixHelp,MODE_OLDFILE)))
    {
-		ulong err=osError();
+		uint32_t err=osError();
       LogWrite(1,SYSTEMERR,"AreaFix: Unable to open %s",config.cfg_AreaFixHelp);
 		LogWrite(1,SYSTEMERR,"AreaFix: Error: %s",osErrorMsg(err));
       afAddLine(afr,"*** Error *** : Couldn't open help file");
@@ -1331,12 +1333,12 @@ void rawSendHelp(struct Node4D *from4d,uchar *toname,struct ConfigNode *cnode)
 	afFreeReply(afr);
 }
 
-void rawSendInfo(struct Node4D *from4d,uchar *toname,struct ConfigNode *cnode)
+void rawSendInfo(struct Node4D *from4d,char *toname,struct ConfigNode *cnode)
 {
    int c;
 	struct afReply *afr;
 	
-   LogWrite(4,AREAFIX,"AreaFix: Sending configuration info to %lu:%lu/%lu.%lu",
+   LogWrite(4,AREAFIX,"AreaFix: Sending configuration info to %u:%u/%u.%u",
       cnode->Node.Zone,
       cnode->Node.Net,
       cnode->Node.Node,
@@ -1345,7 +1347,7 @@ void rawSendInfo(struct Node4D *from4d,uchar *toname,struct ConfigNode *cnode)
    if(!(afr=afInitReply(config.cfg_Sysop,from4d,toname,&cnode->Node,"AreaFix configuration info")))
 		return;
 
-   afAddLine(afr,"Configuration for %lu:%lu/%lu.%lu:",
+   afAddLine(afr,"Configuration for %u:%u/%u.%u:",
       cnode->Node.Zone,
       cnode->Node.Net,
       cnode->Node.Node,
@@ -1424,7 +1426,7 @@ void rawSendInfo(struct Node4D *from4d,uchar *toname,struct ConfigNode *cnode)
 
 void afRawPrepareMessage(void);
 
-struct afReply *afInitReply(uchar *fromname,struct Node4D *from4d,uchar *toname,struct Node4D *to4d,uchar *subject)
+struct afReply *afInitReply(char *fromname,struct Node4D *from4d,char *toname,struct Node4D *to4d,char *subject)
 {
 	struct afReply *afr;
 	
@@ -1463,17 +1465,17 @@ void afFreeReply(struct afReply *afr)
 	mmFree(afr->mm);
 }
 
-void afAddLine(struct afReply *afr,uchar *fmt,...)
+void afAddLine(struct afReply *afr,char *fmt,...)
 {
    va_list args;
-   uchar buf[200];
+   char buf[200];
 
    if(afr->lines >= config.cfg_AreaFixMaxLines-2 && config.cfg_AreaFixMaxLines!=0)
    {
       strcpy(buf,"\x0d(Continued in next message)\x0d");
 		mmAddLine(afr->mm,buf);
 
-      sprintf(afr->mm->Subject,"%s (part %ld)",afr->subject,afr->part);
+      sprintf(afr->mm->Subject,"%s (part %d)",afr->subject,afr->part);
       afSendMessage(afr);
       jbFreeList(&afr->mm->TextChunks);
 
@@ -1501,7 +1503,7 @@ void afAddLine(struct afReply *afr,uchar *fmt,...)
 void afSendMessage(struct afReply *afr)
 {
    if(afr->part != 1) 
-		sprintf(afr->mm->Subject,"%s (part %ld)",afr->subject,afr->part);
+		sprintf(afr->mm->Subject,"%s (part %d)",afr->subject,afr->part);
 
 	else					
 		strcpy(afr->mm->Subject,afr->subject);
@@ -1510,7 +1512,7 @@ void afSendMessage(struct afReply *afr)
 }
 
 
-void RemoteAreafixAdd(uchar *area,struct ConfigNode *node)
+void RemoteAreafixAdd(char *area,struct ConfigNode *node)
 {
    struct RemoteAFCommand *cmd;
 
@@ -1530,7 +1532,7 @@ void RemoteAreafixAdd(uchar *area,struct ConfigNode *node)
    jbAddNode(&node->RemoteAFList,(struct jbNode *)cmd);
 }
 
-void RemoteAreafixRemove(uchar *area,struct ConfigNode *node)
+void RemoteAreafixRemove(char *area,struct ConfigNode *node)
 {
    struct RemoteAFCommand *cmd;
 
@@ -1551,7 +1553,7 @@ void SendRemoteAreafix(void)
    struct Route *tmproute;
    struct ConfigNode *node;
    struct RemoteAFCommand *cmd;
-   uchar buf[200];
+   char buf[200];
    struct MemMessage *mm;
 
    for(node=(struct ConfigNode *)config.CNodeList.First;node;node=node->Next)
@@ -1600,9 +1602,9 @@ void SendRemoteAreafix(void)
       }
 }
 
-bool CheckFlags(uchar group,uchar *node)
+bool CheckFlags(char group,char *node)
 {
-   uchar c;
+   uint8_t c;
 
    for(c=0;c<strlen(node);c++)
    {
@@ -1613,11 +1615,11 @@ bool CheckFlags(uchar group,uchar *node)
    return(FALSE);
 }
 
-struct Arealist *FindForward(uchar *tagname,uchar *flags)
+struct Arealist *FindForward(char *tagname,char *flags)
 {
    struct Arealist *arealist;
-   uchar buf[200];
-   ulong c;
+   char buf[200];
+   uint32_t c;
    osFile fh;
 
    for(arealist=(struct Arealist *)config.ArealistList.First;arealist;arealist=arealist->Next)
@@ -1641,7 +1643,7 @@ struct Arealist *FindForward(uchar *tagname,uchar *flags)
          }
 			else
 			{
-				ulong err=osError();
+				uint32_t err=osError();
 				LogWrite(1,SYSTEMERR,"Failed to open file %s",arealist->AreaFile);
 				LogWrite(1,SYSTEMERR,"Error: %s",osErrorMsg(err));
 			}
@@ -1659,7 +1661,7 @@ void DoSendAFList(short type,struct ConfigNode *cnode)
 
    if(!tmproute)
    {
-      LogWrite(1,TOSSINGERR,"No route found for %ld:%ld/%ld.%ld",
+      LogWrite(1,TOSSINGERR,"No route found for %d:%d/%d.%d",
          cnode->Node.Zone,
          cnode->Node.Net,
          cnode->Node.Node,
