@@ -1,10 +1,10 @@
 #include "crashmail.h"
 
-extern uchar *config_version;
+extern char *config_version;
 
-bool CorrectFlags(uchar *flags)
+bool CorrectFlags(char *flags)
 {
-   ulong c;
+   uint32_t c;
 
    for(c=0;c<strlen(flags);c++)
    {
@@ -17,12 +17,12 @@ bool CorrectFlags(uchar *flags)
    return(TRUE);
 }
 
-uchar cfgbuf[4000];
+char cfgbuf[4000];
 
-bool ReadConfig(uchar *filename,struct Config *cfg,short *seconderr,ulong *cfgline,uchar *cfgerr)
+bool ReadConfig(char *filename,struct Config *cfg,short *seconderr,uint32_t *cfgline,char *cfgerr)
 {
-   uchar buf2[200],cfgword[30];
-   ulong c,d,jbcpos;
+   char buf2[200],cfgword[30];
+   uint32_t c,d,jbcpos;
    osFile cfgfh;
    
    struct Aka           *tmpaka,    *LastAka=NULL;
@@ -44,7 +44,7 @@ bool ReadConfig(uchar *filename,struct Config *cfg,short *seconderr,ulong *cfgli
    struct BannedNode *tmpbnode;
    struct Node4D     tmp4d;
 
-   ushort flags;
+   uint16_t flags;
 
    cfg->changed=FALSE;
    mystrncpy(cfg->filename,filename,100);
@@ -1468,7 +1468,7 @@ bool ReadConfig(uchar *filename,struct Config *cfg,short *seconderr,ulong *cfgli
             return(FALSE);
          }
 
-         if(!(tmpcommand->string=(uchar *)osAlloc(strlen(buf2)+1)))
+         if(!(tmpcommand->string=(char *)osAlloc(strlen(buf2)+1)))
          {
             *seconderr=READCONFIG_NO_MEM;
             osClose(cfgfh);
@@ -1504,7 +1504,7 @@ bool ReadConfig(uchar *filename,struct Config *cfg,short *seconderr,ulong *cfgli
             return(FALSE);
          }
 
-         if(!(tmpcommand->string=(uchar *)osAlloc(strlen(buf2)+1)))
+         if(!(tmpcommand->string=(char *)osAlloc(strlen(buf2)+1)))
          {
             *seconderr=READCONFIG_NO_MEM;
             osClose(cfgfh);
@@ -1777,7 +1777,7 @@ bool ReadConfig(uchar *filename,struct Config *cfg,short *seconderr,ulong *cfgli
    return(TRUE);
 }
 
-bool CheckConfig(struct Config *cfg,uchar *cfgerr)
+bool CheckConfig(struct Config *cfg,char *cfgerr)
 {
    struct Area *a1,*a2;
    struct PatternNode *patternnode;
@@ -1785,7 +1785,7 @@ bool CheckConfig(struct Config *cfg,uchar *cfgerr)
    struct Change *change;
    struct Filter *filter;
    struct Command *command;
-   uchar buf[50];
+   char buf[50];
 
    if(cfg->cfg_TempDir[0]==0)      strcpy(cfg->cfg_TempDir,cfg->cfg_Inbound);
    if(cfg->cfg_PacketCreate[0]==0) strcpy(cfg->cfg_PacketCreate,cfg->cfg_Outbound);
@@ -1922,10 +1922,10 @@ void InitConfig(struct Config *cfg)
    jbNewList(&cfg->FilterList);
 }
 
-void WriteSafely(osFile fh,uchar *str)
+void WriteSafely(osFile fh,char *str)
 {
-   uchar buf[300];
-   ushort c,d;
+   char buf[300];
+   uint16_t c,d;
 
    d=0;
 
@@ -1944,13 +1944,13 @@ void WriteSafely(osFile fh,uchar *str)
 
 void WriteNode4D(osFile fh,struct Node4D *n4d)
 {
-   osFPrintf(fh,"%lu:%lu/%lu.%lu",n4d->Zone,n4d->Net,n4d->Node,n4d->Point);
+   osFPrintf(fh,"%u:%u/%u.%u",n4d->Zone,n4d->Net,n4d->Node,n4d->Point);
 }
 
-uchar *nodekeywords[]={"DEFAULTGROUP","REMOTESYSOP","REMOTEAF",
+char *nodekeywords[]={"DEFAULTGROUP","REMOTESYSOP","REMOTEAF",
                        "AREAFIXINFO","NODE","PKTFROM",NULL};
 
-uchar *areakeywords[]={"IGNORESEENBY","IGNOREDUPES","DEFREADONLY",
+char *areakeywords[]={"IGNORESEENBY","IGNOREDUPES","DEFREADONLY",
                        "MANDATORY","UNCONFIRMED","KEEPNUM","KEEPDAYS",
                        "GROUP","DESCRIPTION","BANNED","EXPORT","IMPORT",
                        "AREA","NETMAIL",NULL};
@@ -2062,7 +2062,7 @@ void WriteArea(struct Area *tmparea,osFile osfh)
    struct ImportNode *tmpinode;
    struct TossNode   *tmptnode;
    struct BannedNode *tmpbnode;
-   ulong c;
+   uint32_t c;
 
    if(tmparea->AreaType == AREATYPE_NETMAIL)
       osFPrintf(osfh,"NETMAIL ");
@@ -2161,10 +2161,10 @@ void WriteArea(struct Area *tmparea,osFile osfh)
       osFPrintf(osfh,"GROUP %lc\n",tmparea->Group);
 
    if(tmparea->KeepNum)
-      osFPrintf(osfh,"KEEPNUM %lu\n",tmparea->KeepNum);
+      osFPrintf(osfh,"KEEPNUM %u\n",tmparea->KeepNum);
 
    if(tmparea->KeepDays)
-      osFPrintf(osfh,"KEEPDAYS %lu\n",tmparea->KeepDays);
+      osFPrintf(osfh,"KEEPDAYS %u\n",tmparea->KeepDays);
 
    if(tmparea->Flags & AREA_UNCONFIRMED)
       osFPrintf(osfh,"UNCONFIRMED\n");
@@ -2182,16 +2182,16 @@ void WriteArea(struct Area *tmparea,osFile osfh)
       osFPrintf(osfh,"IGNORESEENBY\n");
 }
 
-bool UpdateConfig(struct Config *cfg,uchar *cfgerr)
+bool UpdateConfig(struct Config *cfg,char *cfgerr)
 {
-   uchar cfgtemp[110],cfgbak[110];
-   uchar cfgword[30],buf[100];
+   char cfgtemp[110],cfgbak[110];
+   char cfgword[30],buf[100];
    osFile oldfh,newfh;
    bool skiparea,skipnode,dontwrite,copyres;
    struct ConfigNode    *cnode;
    struct Area          *area;
    struct Node4D n4d;
-   ulong jbcpos,c;
+   uint32_t jbcpos,c;
 
    strcpy(cfgtemp,cfg->filename);
    strcat(cfgtemp,".tmp");
@@ -2201,14 +2201,14 @@ bool UpdateConfig(struct Config *cfg,uchar *cfgerr)
 
    if(!(oldfh=osOpen(cfg->filename,MODE_OLDFILE)))
    {
-		ulong err=osError();
+		uint32_t err=osError();
       sprintf(cfgerr,"Unable to read file %s (error: %s)",cfg->filename,osErrorMsg(err));
       return(FALSE);
    }
 
    if(!(newfh=osOpen(cfgtemp,MODE_NEWFILE)))
    {
-		ulong err=osError();
+		uint32_t err=osError();
       sprintf(cfgerr,"Unable to write to config file %s (error: %s)",cfgtemp,osErrorMsg(err));
       osClose(oldfh);
       return(FALSE);
