@@ -5,9 +5,9 @@
 
 struct Nodelist
 {
-   uchar *name;
-   uchar *desc;
-   bool (*nlStart)(uchar *errbuf);
+   char *name;
+   char *desc;
+   bool (*nlStart)(char *errbuf);
    void (*nlEnd)(void);
    bool (*nlCheckNode)(struct Node4D *node);
    long (*nlGetHub)(struct Node4D *node);
