@@ -1,2 +1,2 @@
-bool SafeDelete(uchar *file);
+bool SafeDelete(char *file);
 void ProcessSafeDelete(void);
