@@ -15,11 +15,15 @@
     You should have received a copy of the GNU Lesser General Public
     License along with this library; if not, write to the Free Software
     Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
-*/	 
+
+    Changes made by Johan Billing 2003-10-22
+
+    - Fixed comparison between signed and unsigned variable in JAM_Crc32()
+*/
 
 #include "jam.h"
 
-ulong crc32tab[] = { /* CRC polynomial 0xedb88320 */
+uint32_t crc32tab[] = { /* CRC polynomial 0xedb88320 */
 0x00000000, 0x77073096, 0xee0e612c, 0x990951ba, 0x076dc419, 0x706af48f, 0xe963a535, 0x9e6495a3,
 0x0edb8832, 0x79dcb8a4, 0xe0d5e91e, 0x97d2d988, 0x09b64c2b, 0x7eb17cbd, 0xe7b82d07, 0x90bf1d91,
 0x1db71064, 0x6ab020f2, 0xf3b97148, 0x84be41de, 0x1adad47d, 0x6ddde4eb, 0xf4d4b551, 0x83d385c7,
@@ -54,15 +58,21 @@ ulong crc32tab[] = { /* CRC polynomial 0xedb88320 */
 0xb3667a2e, 0xc4614ab8, 0x5d681b02, 0x2a6f2b94, 0xb40bbe37, 0xc30c8ea1, 0x5a05df1b, 0x2d02ef8d
 };
 
-ulong JAM_Crc32(uchar *Buffer_PC, ulong Length_I)
+/***********************************************************************
+**
+**  JAM_Crc32 - Calculates CRC-32
+**
+***********************************************************************/
+
+uint32_t JAM_Crc32(char *Buffer_PC, uint32_t Length_I)
 {
-   ulong Crc_I;
-   int c;
+   uint32_t Crc_I;
+   uint32_t c;
 
    Crc_I=0xffffffff;
 
    for(c=0;c < Length_I; c++)
-      Crc_I=(Crc_I>>8) ^ crc32tab[(uchar)Crc_I ^ tolower(Buffer_PC[c])];
+      Crc_I=(Crc_I>>8) ^ crc32tab[(char)Crc_I ^ tolower(Buffer_PC[c])];
 
    return(Crc_I);
 }
