@@ -5,13 +5,13 @@
 
 struct Node4D
 {
-   ushort Zone,Net,Node,Point;
+   uint16_t Zone,Net,Node,Point;
 };
 
-bool Parse4D(uchar *buf, struct Node4D *node);
-bool Parse4DTemplate(uchar *buf, struct Node4D *node,struct Node4D *tpl);
+bool Parse4D(char *buf, struct Node4D *node);
+bool Parse4DTemplate(char *buf, struct Node4D *node,struct Node4D *tpl);
 void Copy4D(struct Node4D *node1,struct Node4D *node2);
 int Compare4D(struct Node4D *node1,struct Node4D *node2);
-void Print4D(struct Node4D *n4d,uchar *dest);
+void Print4D(struct Node4D *n4d,char *dest);
 
 #endif
